/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLAnchorElement.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLAnchorElement.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLAnchorElement.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateIntGdomHTMLAnchorElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLAnchorElement::GDOMHTMLAnchorElement(PassRefPtr<WebCore::HTMLAnchorElement> impl)
    : GDOMHTMLElement(impl)
{
}

gchar *
gdom_html_anchor_element_to_string (GdomHTMLAnchorElement *thiz)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::HTMLAnchorElement * item = (gdom_html_anchor_element_get_private(thiz));
    g_return_val_if_fail (item, 0);
    gchar * res = _G_GET_UTF8(item->toString());
    return res;

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLAnchorElement.h"
#include <gdom/GdomHTMLAnchorElement.h>
#include <gdom/PrivateGdomHTMLAnchorElement.h>
#include <gdom/PrivateIntGdomHTMLAnchorElement.h>
#include <gdom/GdomHTMLAnchorElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLAnchorElement, gdom_html_anchor_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLAnchorElementPrivate {
    class WebCore::HTMLAnchorElement *item;
};

#define GDOM_HTML_ANCHOR_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_ANCHOR_ELEMENT, GdomHTMLAnchorElementPrivate))
*/
G_END_DECLS
WebCore::HTMLAnchorElement *
gdom_html_anchor_element_get_private(GdomHTMLAnchorElement *request)
{
    GDOMHTMLAnchorElement *res;
    res = static_cast<GDOMHTMLAnchorElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLAnchorElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_ACCESS_KEY,
    PROP_CHARSET,
    PROP_COORDS,
    PROP_HREF,
    PROP_HREFLANG,
    PROP_NAME,
    PROP_REL,
    PROP_REV,
    PROP_SHAPE,
    PROP_TARGET,
    PROP_TYPE,
    PROP_HASH,
    PROP_HOST,
    PROP_HOSTNAME,
    PROP_PATHNAME,
    PROP_PORT,
    PROP_PROTOCOL,
    PROP_SEARCH,
    PROP_TEXT,
};


static void gdom_html_anchor_element_finalize(GObject* object)
{
    /*GdomHTMLAnchorElement* request = GDOM_HTML_ANCHOR_ELEMENT(object);*/
    /*GdomHTMLAnchorElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_anchor_element_parent_class)->finalize(object);
}

static void gdom_html_anchor_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLAnchorElement *self = GDOM_HTML_ANCHOR_ELEMENT(object);
    WebCore::HTMLAnchorElement * gself = (gdom_html_anchor_element_get_private(self));
    switch (prop_id) {
     case PROP_ACCESS_KEY:
    {
         gself->setAccessKey(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CHARSET:
    {
         gself->setCharset(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_COORDS:
    {
         gself->setCoords(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HREF:
    {
         gself->setHref(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HREFLANG:
    {
         gself->setHreflang(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_NAME:
    {
         gself->setName(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_REL:
    {
         gself->setRel(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_REV:
    {
         gself->setRev(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_SHAPE:
    {
         gself->setShape(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_TARGET:
    {
         gself->setTarget(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_TYPE:
    {
         gself->setType(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_anchor_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLAnchorElement *self = GDOM_HTML_ANCHOR_ELEMENT(object);
    WebCore::HTMLAnchorElement * gself = (gdom_html_anchor_element_get_private(self));
    switch (prop_id) {
    case PROP_ACCESS_KEY:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->accessKey()));
         break;
    }
    case PROP_CHARSET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->charset()));
         break;
    }
    case PROP_COORDS:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->coords()));
         break;
    }
    case PROP_HREF:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->href()));
         break;
    }
    case PROP_HREFLANG:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->hreflang()));
         break;
    }
    case PROP_NAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->name()));
         break;
    }
    case PROP_REL:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->rel()));
         break;
    }
    case PROP_REV:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->rev()));
         break;
    }
    case PROP_SHAPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->shape()));
         break;
    }
    case PROP_TARGET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->target()));
         break;
    }
    case PROP_TYPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->type()));
         break;
    }
    case PROP_HASH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->hash()));
         break;
    }
    case PROP_HOST:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->host()));
         break;
    }
    case PROP_HOSTNAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->hostname()));
         break;
    }
    case PROP_PATHNAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->pathname()));
         break;
    }
    case PROP_PORT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->port()));
         break;
    }
    case PROP_PROTOCOL:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->protocol()));
         break;
    }
    case PROP_SEARCH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->search()));
         break;
    }
    case PROP_TEXT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->text()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_anchor_element_class_init(GdomHTMLAnchorElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_anchor_element_finalize;
    g_klass->set_property = gdom_html_anchor_element__set_property_fn;
    g_klass->get_property = gdom_html_anchor_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_ACCESS_KEY,
            g_param_spec_string ("access_key", /* name */
                "html_anchor_element_access_key", /* short description */
                "read-write  gchar * HTMLAnchorElement.access_key", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CHARSET,
            g_param_spec_string ("charset", /* name */
                "html_anchor_element_charset", /* short description */
                "read-write  gchar * HTMLAnchorElement.charset", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_COORDS,
            g_param_spec_string ("coords", /* name */
                "html_anchor_element_coords", /* short description */
                "read-write  gchar * HTMLAnchorElement.coords", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HREF,
            g_param_spec_string ("href", /* name */
                "html_anchor_element_href", /* short description */
                "read-write  gchar * HTMLAnchorElement.href", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HREFLANG,
            g_param_spec_string ("hreflang", /* name */
                "html_anchor_element_hreflang", /* short description */
                "read-write  gchar * HTMLAnchorElement.hreflang", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_NAME,
            g_param_spec_string ("name", /* name */
                "html_anchor_element_name", /* short description */
                "read-write  gchar * HTMLAnchorElement.name", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_REL,
            g_param_spec_string ("rel", /* name */
                "html_anchor_element_rel", /* short description */
                "read-write  gchar * HTMLAnchorElement.rel", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_REV,
            g_param_spec_string ("rev", /* name */
                "html_anchor_element_rev", /* short description */
                "read-write  gchar * HTMLAnchorElement.rev", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_SHAPE,
            g_param_spec_string ("shape", /* name */
                "html_anchor_element_shape", /* short description */
                "read-write  gchar * HTMLAnchorElement.shape", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_TARGET,
            g_param_spec_string ("target", /* name */
                "html_anchor_element_target", /* short description */
                "read-write  gchar * HTMLAnchorElement.target", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_TYPE,
            g_param_spec_string ("type", /* name */
                "html_anchor_element_type", /* short description */
                "read-write  gchar * HTMLAnchorElement.type", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HASH,
            g_param_spec_string ("hash", /* name */
                "html_anchor_element_hash", /* short description */
                "read-only  gchar * HTMLAnchorElement.hash", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_HOST,
            g_param_spec_string ("host", /* name */
                "html_anchor_element_host", /* short description */
                "read-only  gchar * HTMLAnchorElement.host", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_HOSTNAME,
            g_param_spec_string ("hostname", /* name */
                "html_anchor_element_hostname", /* short description */
                "read-only  gchar * HTMLAnchorElement.hostname", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_PATHNAME,
            g_param_spec_string ("pathname", /* name */
                "html_anchor_element_pathname", /* short description */
                "read-only  gchar * HTMLAnchorElement.pathname", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_PORT,
            g_param_spec_string ("port", /* name */
                "html_anchor_element_port", /* short description */
                "read-only  gchar * HTMLAnchorElement.port", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_PROTOCOL,
            g_param_spec_string ("protocol", /* name */
                "html_anchor_element_protocol", /* short description */
                "read-only  gchar * HTMLAnchorElement.protocol", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_SEARCH,
            g_param_spec_string ("search", /* name */
                "html_anchor_element_search", /* short description */
                "read-only  gchar * HTMLAnchorElement.search", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_TEXT,
            g_param_spec_string ("text", /* name */
                "html_anchor_element_text", /* short description */
                "read-only  gchar * HTMLAnchorElement.text", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLAnchorElementPrivate));*/
}

static void gdom_html_anchor_element_init(GdomHTMLAnchorElement* request)
{
    /*GdomHTMLAnchorElementPrivate* priv = GDOM_HTML_ANCHOR_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

